[data-v-320e9ff3]:root{--main-font-family: DM Sans, sans-serif}[data-v-320e9ff3]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.sidebar[data-v-320e9ff3]{height:100%;box-sizing:border-box;display:flex;flex-direction:column;gap:28px;overflow:auto}@media screen and (min-width: 600px){.sidebar[data-v-320e9ff3]{min-width:200px}}.sidebar .section[data-v-320e9ff3]{display:flex;flex-direction:column;min-width:160px;gap:10px;color:#6d7c93;font-weight:500;font-size:.65rem;text-transform:uppercase}.sidebar .item[data-v-320e9ff3]{padding:6px 10px;width:100%;box-sizing:border-box;display:flex;gap:10px;align-items:center;border-radius:.5rem;border-radius:8px;color:#4e596a;fill:#4e596a;text-transform:initial;font-weight:500;font-size:.8rem}.sidebar .item[data-v-320e9ff3]:not(.disabled):not(.active):not(:active){cursor:pointer}.sidebar .item .warning[data-v-320e9ff3]{margin-left:auto;display:flex;align-items:center;justify-content:center}.sidebar .item .tag[data-v-320e9ff3]{display:block;font-size:8px;color:#fff;padding:4px;border-radius:5px}.sidebar .item .tag.beta[data-v-320e9ff3]{background-color:#d56d6d}.sidebar .item .tag.soon[data-v-320e9ff3]{background-color:#c8c8c8}.sidebar .item .tag.cloud[data-v-320e9ff3]{background-color:#a5b2ff}.sidebar .item .icon[data-v-320e9ff3] path{fill:#4e596a}.sidebar .item.disabled[data-v-320e9ff3]{color:#bbb}.sidebar .item.disabled .icon[data-v-320e9ff3] path{fill:#bbb}.sidebar .item .item-name[data-v-320e9ff3]{font-size:14px;font-weight:500;line-height:16px;letter-spacing:0em}.sidebar .item[data-v-320e9ff3]:hover:not(.disabled):not(.active):not(:active){background:#ffffff;color:#343b46;font-weight:600;box-shadow:0 0 15px #0000000a}.sidebar .item:hover:not(.disabled):not(.active):not(:active) .icon[data-v-320e9ff3] path{fill:#343b46}.sidebar .item[data-v-320e9ff3]:active:not(.disabled),.sidebar .item.active[data-v-320e9ff3]{background:#edeff2;color:#292f37;font-weight:700}.sidebar .item:active:not(.disabled) .icon[data-v-320e9ff3] path,.sidebar .item.active .icon[data-v-320e9ff3] path{fill:#292f37}@media screen and (max-width: 600px){.sidebar .section-name[data-v-320e9ff3],.sidebar .item-name[data-v-320e9ff3]{display:none}.sidebar .section[data-v-320e9ff3]{min-width:34px;min-height:34px}.sidebar .section[data-v-320e9ff3],.sidebar .sidebar[data-v-320e9ff3]{gap:10px}.sidebar .item[data-v-320e9ff3]{flex-direction:column;gap:0}}.logo[data-v-ccfb70ef]{display:flex;align-items:center}.logo img[data-v-ccfb70ef]{height:50px}.logo span[data-v-ccfb70ef]{font-size:18px;font-weight:600;margin-left:10px}[data-v-279534de]:root{--main-font-family: DM Sans, sans-serif}[data-v-279534de]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.login-block[data-v-279534de]{display:flex;align-items:center;gap:5px}.login-block .button[data-v-279534de]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;background:#2479df;color:#fff;box-shadow:0 2px 4px #00000026}.login-block .button[data-v-279534de]:hover{background:#448add;box-shadow:0 4px 12px #00000026}.login-block .button[data-v-279534de]:active,.login-block .button active[data-v-279534de]{background:#448add;box-shadow:inset 0 4px 4px #0000000f}[data-v-91804c74]:root{--main-font-family: DM Sans, sans-serif}[data-v-91804c74]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}nav[data-v-91804c74]{display:flex;align-items:center;justify-content:space-between;box-shadow:0 0 100px #00000005;height:48px;padding:0 16px}.workspace[data-v-91804c74]{display:flex;max-width:100vw;box-sizing:border-box;gap:20px;padding:30px 20px;height:fit-content}.workspace .sidebar[data-v-91804c74]{position:sticky;top:30px}
